@@ -102,12 +102,13 @@ void AbstractContactDelegate::paintHeader(QPainter *painter, const QStyleOptionV
 
     QStyleOption expandSignOption = option;
     expandSignOption.rect = groupRect;
-    expandSignOption.rect.setSize(QSize(iconSize, iconSize));
+    //FIXME hardcoded magic...though corresponds with the list indentation
+    expandSignOption.rect.setSize(QSize(14, iconSize));
     expandSignOption.rect.moveLeft(groupRect.left());
     expandSignOption.rect.moveTop(groupRect.top() + groupRect.height()/2 - expandSignOption.rect.height()/2);
     // simulates mouseover to highlight arrow when selected with keyboard
     if (option.state & QStyle::State_Selected) {
-	expandSignOption.state |= QStyle::State_MouseOver;
+        expandSignOption.state |= QStyle::State_MouseOver;
     }
 
     //paint the expand sign
